<?xml version="1.0" encoding="UTF-8"?>
<!-- **************************************************************************
 *  IBM CONFIDENTIAL
 *  OCO SOURCE MATERIALS
 *
 *  COPYRIGHT:  P#2 P#1
 *              (C) COPYRIGHT IBM CORPORATION Y1, Y2
 *
 *  The source code for this program is not published or otherwise divested of
 *  its trade secrets, irrespective of what has been deposited with the U.S.
 *  Copyright Office.
 *
 *  Source File Name =   (%W%)
 *
 *  Descriptive Name = Database login stylesheet
 *
 *  Function: displays a screen that allows the user to login to an database
 *            in a previously chosen system/instance.
 *
 *  Dependencies: See import list.
 *
 *  Restrictions:
 *
 *  Change Activity:
 *    DATE    DESCRIPTION                                             S&D Code
 *  02/Feb/08 Initial Version                                        @f210126cmw
 *  02/Feb/17 Add persistant data                                    @d211838hab
 *  02/Apr/08 Add target access key param                            @d223561hab
 *  02/May/23 Add new_target param to keep track of selected target  @d235104hab
 *
 *  ===========================================================================
 *
 *  Last Changed = %E% %U%*
 *
 ************************************************************************** -->

<outout:stylesheet xmlns:outout="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <outout:output method="xml" omit-xml-declaration="yes" />

  <!-- PARAM DECLARATION AREA -->
  <outout:param name="ccwa_pda_login_database_system" />
  <outout:param name="ccwa_pda_login_database_instance" />
  <outout:param name="ccwa_pda_login_database_database" />
  <outout:param name="ccwa_pda_login_database_change" />
  <outout:param name="ccwa_pda_login_database_userid" />
  <outout:param name="ccwa_pda_login_database_password" />
  <outout:param name="ccwa_pda_login_database_ok" />
  <outout:param name="ccwa_pda_login_database_cancel" />

  <outout:param name="system_value" />
  <outout:param name="instance_value" />
  <outout:param name="database_value" />

  <!-- new target param used to hold value of object we are trying to login to -->
  <outout:param name="new_target_param" />
  <outout:param name="new_target_value" />

  <!-- target_access_key is used to uniquely identify the requested target access -->
  <outout:param name="target_access_key" />
  <outout:param name="target_access_key_value" />

  <outout:param name="cc_selected_function_param" />
  <outout:param name="cc_selected_function_value" />

  <outout:param name="req_uri_param" />
  <outout:param name="sid_param" />
  <outout:param name="cs_param"  />
  <outout:param name="event_param" />
  <outout:param name="cs_value" />
  <outout:param name="sid_value" />

  <!-- EVENTS -->
  <!-- "change_system" -->
  <!-- "change_instance" -->

  <!-- start of rule to match root -->
  <outout:template match="/">

    <body>
      <outout:value-of select="$ccwa_pda_login_database_system" />
      &#160;
      <outout:value-of select="$system_value" />
      &#160;
      <a>
        <outout:call-template name="queryString">
          <outout:with-param name="event">
            <outout:value-of select="'change_system'" />
          </outout:with-param>
        </outout:call-template>
        <outout:value-of select="$ccwa_pda_login_database_change" />
      </a>
      <br />
      <outout:value-of select="$ccwa_pda_login_database_instance" />
      &#160;
      <outout:value-of select="$instance_value" />
      &#160;
      <a>
        <outout:call-template name="queryString">
          <outout:with-param name="event">
            <outout:value-of select="'change_instance'" />
          </outout:with-param>
        </outout:call-template>
        <outout:value-of select="$ccwa_pda_login_database_change" />
      </a>
      <br />
      <outout:value-of select="$ccwa_pda_login_database_database" />
      &#160;
      <outout:value-of select="$database_value" />
      <br />
      <form name="login" method="post" action="{$req_uri_param}">
        <hr />
        <b>
          <outout:value-of select="$ccwa_pda_login_database_userid" />
        </b>
        <br />
        <input type="text" size="20" name="userid" />
        <br />
        <b>
          <outout:value-of select="$ccwa_pda_login_database_password" />
        </b>
        <br />
        <input type="password" size="20" name="password" />
        <br /><br />
        <input type="submit" name="okBtn">
          <outout:attribute name="value">
            <outout:value-of select="$ccwa_pda_login_database_ok" />
          </outout:attribute>
        </input>
        &#160;
        <input type="submit" name="cancelBtn">
          <outout:attribute name="value">
            <outout:value-of select="$ccwa_pda_login_database_cancel" />
          </outout:attribute>
        </input>

        <outout:call-template name='makeStandardHiddenFields'>
          <outout:with-param name='event' select="'btnClick'" />
        </outout:call-template>

        <outout:call-template name='makeHiddenFields' />

      </form>
    </body>

  </outout:template>

	<outout:template name='queryString'>
	  <outout:param name='event'/>

    <outout:variable name='standard_params'>
      <outout:value-of select="concat( $req_uri_param, '?', $cs_param, '=', $cs_value, '&amp;', $sid_param, '=', $sid_value, '&amp;', $event_param, '=', $event)"/>
    </outout:variable>
    <outout:variable name='target_pair'>
      <outout:value-of select="concat( '&amp;', $target_access_key, '=', $target_access_key_value )" />
    </outout:variable>
    <outout:variable name='function_pair'>
      <outout:value-of select="concat( '&amp;', $cc_selected_function_param, '=', $cc_selected_function_value )" />
    </outout:variable>

	  <outout:attribute name='href'>
  	  <outout:value-of select="concat( $standard_params, $function_pair, $target_pair )"/>
	  </outout:attribute>
	</outout:template>

  <outout:template name='makeStandardHiddenFields'>
    <outout:param name='event'/>
    <input type='hidden'>
      <outout:attribute name='name'>
        <outout:value-of select='$cs_param'/>
      </outout:attribute>
      <outout:attribute name='value'>
        <outout:value-of select='$cs_value'/>
      </outout:attribute>
    </input>
    <input type='hidden'>
      <outout:attribute name='name'>
        <outout:value-of select='$sid_param'/>
      </outout:attribute>
      <outout:attribute name='value'>
        <outout:value-of select='$sid_value'/>
      </outout:attribute>
    </input>
    <input type='hidden'>
      <outout:attribute name='name'>
        <outout:value-of select='$event_param'/>
      </outout:attribute>
      <outout:attribute name='value'>
        <outout:value-of select='$event'/>
      </outout:attribute>
    </input>
  </outout:template>

	<outout:template name='makeHiddenFields'>
	  <input type='hidden'>
	    <outout:attribute name='name'>
	      <outout:value-of select='$new_target_param'/>
	    </outout:attribute>
	    <outout:attribute name='value'>
	      <outout:value-of select='$new_target_value'/>
	    </outout:attribute>
	  </input>
	  <input type='hidden'>
	    <outout:attribute name='name'>
	      <outout:value-of select='$target_access_key'/>
	    </outout:attribute>
	    <outout:attribute name='value'>
	      <outout:value-of select='$target_access_key_value'/>
	    </outout:attribute>
	  </input>

	  <input type='hidden'>
	    <outout:attribute name='name'>
	      <outout:value-of select='$cc_selected_function_param'/>
	    </outout:attribute>
	    <outout:attribute name='value'>
	      <outout:value-of select='$cc_selected_function_value'/>
	    </outout:attribute>
	  </input>
	</outout:template>

</outout:stylesheet>



